/*
 * Wilcard S100P FXS Interface Driver for Zapata Telephony interface
 *
 * Written by Mark Spencer <markster@linux-support.net>
 *
 * Copyright (C) 2001, Linux Support Services, Inc.
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
 *
 */

#ifndef _PSO_H
#define _PSO_H

#include <linux/ioctl.h>

#define NUM_REGS	  109
#define NUM_INDIRECT_REGS 105


#define PSO800_CARD_ID		0x41434620		// "ACF "

#define WC_BUS_TEST_REG		0x0004

#define PSO_E2P_OPER_FLAG	0x8000
#define PSO_E2P_ADDR_SERIAL	0x0060
#define PSO_E2P_ADDR_DATE	0x0064
#define PSO_E2P_PVDATA_REG	0x0050
#define PSO_E2P_PVDADDR_REG	0x004E

struct pso800_stats {
	int tipvolt;	
	int ringvolt;	
	int batvolt;	
};

struct pso800_regs {
	unsigned char direct[NUM_REGS];
	unsigned short indirect[NUM_INDIRECT_REGS];
};

struct pso800_regop {
	int indirect;
	unsigned char reg;
	unsigned short val;
};

struct pso800_echo_coefs {
	unsigned char acim;
	unsigned char coef1;
	unsigned char coef2;
	unsigned char coef3;
	unsigned char coef4;
	unsigned char coef5;
	unsigned char coef6;
	unsigned char coef7;
	unsigned char coef8;
};

struct pso800_keyregs {
	unsigned int key_high;
	unsigned int key_low;
	unsigned int serial;
	unsigned int date;	
};

#define PSO800_GET_KEY	_IOW (ZT_CODE, 65, struct pso800_keyregs)

#define PSO_KEY_LOW_REG		0x0009
#define PSO_SERIAL_REG		0x0009
#define PSO_KEY_HIGH_REG	0x000A
#define PSO_USERRAND_REG	0x000A


#define PSO_USERRAND_MASK	0x0000FFFF
#define PSO_USERRAND_ENABLE	0x00010000


#endif /* _PSO_H */
